@@ -272,7 +272,7 @@ def push_v2(file_path: str, job_id: int, access_token: str):
     :type job_id: int
     """
     _, extension = os.path.splitext(file_path)
-    if extension != "csv":
+    if extension != ".csv":
         raise ValueError("Expected file extension to be a csv.")
     return push_csv2tog(job_id, file_path, access_token)
 
